==> hs-webkit-0.12.1_1.tbz: lib/ghc-7.0.3/cabal/webkit-0.12.1/register.sh <==
#!/bin/sh
echo 'name: webkit
version: 0.12.1
id: webkit-0.12.1-e3e642c95ed38608f06c5ecbaf1894bb

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: WebKit is a web content engine, derived from KHTML and KJS from KDE, and
             used primarily in Apple'\''s Safari browser.  It is made to be embedded in
             other applications, such as mail readers, or web browsers.
             It is able to display content such as HTML, SVG, XML, and others. It also
             supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and more.
category: Graphics
author: Cjacker Huang, Andy Stewart, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.WebKit.CacheModel
                 Graphics.UI.Gtk.WebKit.Download
                 Graphics.UI.Gtk.WebKit.GeolocationPolicyDecision
                 Graphics.UI.Gtk.WebKit.HitTestResult
                 Graphics.UI.Gtk.WebKit.NetworkRequest
                 Graphics.UI.Gtk.WebKit.NetworkResponse
                 Graphics.UI.Gtk.WebKit.SecurityOrigin
                 Graphics.UI.Gtk.WebKit.SoupAuthDialog
                 Graphics.UI.Gtk.WebKit.WebBackForwardList
                 Graphics.UI.Gtk.WebKit.WebDatabase
                 Graphics.UI.Gtk.WebKit.WebDataSource
                 Graphics.UI.Gtk.WebKit.WebFrame
                 Graphics.UI.Gtk.WebKit.WebHistoryItem
                 Graphics.UI.Gtk.WebKit.WebInspector
                 Graphics.UI.Gtk.WebKit.WebNavigationAction
                 Graphics.UI.Gtk.WebKit.WebPolicyDecision
                 Graphics.UI.Gtk.WebKit.WebResource
                 Graphics.UI.Gtk.WebKit.WebSettings Graphics.UI.Gtk.WebKit.WebView
                 Graphics.UI.Gtk.WebKit.WebWindowFeatures
hidden-modules: Graphics.UI.Gtk.WebKit.Internal
                Graphics.UI.Gtk.WebKit.Types Graphics.UI.Gtk.WebKit.Signals
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/webkit-0.12.1
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/webkit-0.12.1
              /usr/local/lib
hs-libraries: HSwebkit-0.12.1
extra-libraries: webkitgtk-1.0 gtk-x11-2.0 soup-2.4 gdk-x11-2.0
                 atk-1.0 pangocairo-1.0 Xext Xrender Xinerama Xi Xrandr Xcursor
                 Xcomposite Xdamage gdk_pixbuf-2.0 pangoft2-1.0 Xfixes cairo X11
                 pango-1.0 m freetype fontconfig gio-2.0 gobject-2.0 gmodule-2.0
                 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/webkit-1.0
              /usr/local/include/glib-2.0 /usr/local/include/gtk-2.0
              /usr/local/include/libsoup-2.4 /usr/local/lib/gtk-2.0/include
              /usr/local/include/atk-1.0 /usr/local/include/cairo
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng
              /usr/local/include/libxml2
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         cairo-0.12.0-0c72e956066deed849e92270e97178b5
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         glib-0.12.0-8144dd6b871a3f77547c0bef30f04b3e
         gtk-0.12.0-a4fda87069ff09531b8c7279ba868f94
         haskell98-1.1.0.1-b5235617d15eeebf246dacfc99755a36
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         pango-0.12.0-7fcdc5f504aa781bc2b80ff49775a65e
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/webkit-0.12.1/html/webkit.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/webkit-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-webkit-0.12.3.tbz: lib/ghc-7.0.4/cabal/webkit-0.12.3/register.sh <==
#!/bin/sh
echo 'name: webkit
version: 0.12.3
id: webkit-0.12.3-bd6b56ff19c0dd603932b6ccc468e354

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: WebKit is a web content engine, derived from KHTML and KJS from KDE, and
             used primarily in Apple'\''s Safari browser.  It is made to be embedded in
             other applications, such as mail readers, or web browsers.
             It is able to display content such as HTML, SVG, XML, and others. It also
             supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and more.
category: Graphics
author: Cjacker Huang, Andy Stewart, Axel Simon
exposed: True
exposed-modules: Graphics.UI.Gtk.WebKit.CacheModel
                 Graphics.UI.Gtk.WebKit.Download
                 Graphics.UI.Gtk.WebKit.GeolocationPolicyDecision
                 Graphics.UI.Gtk.WebKit.HitTestResult
                 Graphics.UI.Gtk.WebKit.NetworkRequest
                 Graphics.UI.Gtk.WebKit.NetworkResponse
                 Graphics.UI.Gtk.WebKit.SecurityOrigin
                 Graphics.UI.Gtk.WebKit.SoupAuthDialog
                 Graphics.UI.Gtk.WebKit.WebBackForwardList
                 Graphics.UI.Gtk.WebKit.WebDatabase
                 Graphics.UI.Gtk.WebKit.WebDataSource
                 Graphics.UI.Gtk.WebKit.WebFrame
                 Graphics.UI.Gtk.WebKit.WebHistoryItem
                 Graphics.UI.Gtk.WebKit.WebInspector
                 Graphics.UI.Gtk.WebKit.WebNavigationAction
                 Graphics.UI.Gtk.WebKit.WebPolicyDecision
                 Graphics.UI.Gtk.WebKit.WebResource
                 Graphics.UI.Gtk.WebKit.WebSettings Graphics.UI.Gtk.WebKit.WebView
                 Graphics.UI.Gtk.WebKit.WebWindowFeatures
hidden-modules: Graphics.UI.Gtk.WebKit.Internal
                Graphics.UI.Gtk.WebKit.Types Graphics.UI.Gtk.WebKit.Signals
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/webkit-0.12.3
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/webkit-0.12.3
              /usr/local/lib
hs-libraries: HSwebkit-0.12.3
extra-libraries: webkitgtk-1.0 gtk-x11-2.0 soup-2.4 gdk-x11-2.0
                 atk-1.0 pangocairo-1.0 Xext Xrender Xinerama Xi Xrandr Xcursor
                 Xcomposite Xdamage gdk_pixbuf-2.0 pangoft2-1.0 Xfixes cairo X11
                 pango-1.0 m freetype fontconfig gio-2.0 gobject-2.0 gmodule-2.0
                 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/webkit-1.0
              /usr/local/include/glib-2.0 /usr/local/include/gtk-2.0
              /usr/local/include/libsoup-2.4 /usr/local/lib/gtk-2.0/include
              /usr/local/include/atk-1.0 /usr/local/include/cairo
              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng
              /usr/local/include/libxml2
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         cairo-0.12.2-9c54b60c6e5a0dab4d0df6e8c9f11ef1
         glib-0.12.2-4ce526ce8b34c051fc6659d35733dff6
         gtk-0.12.2-41e0692ace99ab26c8e70c17ee8bac2f
         pango-0.12.2-fd4336e3a2d3783d962db3de76be5c4e
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/webkit-0.12.3/html/webkit.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/webkit-0.12.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
